@@ -7,7 +7,7 @@
  *
  * @copyright &copy; 1999-2009 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: imap_general.php 13674 2009-05-11 22:17:35Z pdontthink $
+ * @version $Id: imap_general.php 13733 2009-05-21 17:11:04Z kink $
  * @package squirrelmail
  * @subpackage imap
  */
@@ -973,7 +973,8 @@ function sqimap_get_user_server ($imap_server, $username) {
  * LDAP whatever way to find the users IMAP server.
  */
 function map_yp_alias($username) {
-   $yp = `ypmatch ' . escapeshellarg($username) . ' aliases`;
+   $safe_username = escapeshellarg($username);
+   $yp = `ypmatch $safe_username aliases`;
    return chop(substr($yp, strlen($username)+1));
 }
 
