@@ -5,9 +5,9 @@
  *
  * This contains functions for filebased user prefs locations
  *
- * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @copyright &copy; 1999-2009 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: prefs.php 12577 2007-08-09 06:52:17Z pdontthink $
+ * @version $Id: prefs.php 13549 2009-04-15 22:00:49Z jervfors $
  * @package squirrelmail
  * @subpackage prefs
  */
@@ -144,8 +144,15 @@ function getHashedDir($username, $dir, $hash_dirs = '') {
  * @return array a list of hash dirs for this username
  */
 function computeHashDirs($username) {
-    /* Compute the hash for this user and extract the hash directories. */
-    $hash = base_convert(crc32($username), 10, 16);
+    /* Compute the hash for this user and extract the hash directories.  */
+    /* Note that the crc32() function result will be different on 32 and */
+    /* 64 bit systems, thus the hack below.                              */
+    $crc = crc32($username);
+    if ($crc & 0x80000000) {
+        $crc ^= 0xffffffff;
+        $crc += 1;
+    }
+    $hash = base_convert($crc, 10, 16);
     $hash_dirs = array();
     for ($h = 0; $h < 4; ++ $h) {
         $hash_dirs[] = substr($hash, $h, 1);
