@@ -3,12 +3,13 @@
 /**
  * mail_fetch/options.php
  *
- * Copyright (c) 1999-2006 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * Setup of the mailfetch plugin.
  *
- * $Id: options.php 12472 2007-06-25 20:17:12Z kink $
+ * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: options.php 13546 2009-04-15 18:22:55Z jervfors $
+ * @package plugins
+ * @subpackage mail_fetch
  */
 
 define('SM_PATH','../../');
@@ -17,6 +18,11 @@ require_once(SM_PATH . 'include/validate.php');
 require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'include/load_prefs.php');
 
+// don't load this page if this plugin is not enabled
+//
+global $plugins;
+if (!in_array('mail_fetch', $plugins)) exit;
+
 /* globals */
 sqgetGlobalVar('username',   $username,   SQ_SESSION);
 sqgetGlobalVar('key',        $key,        SQ_COOKIE);
