@@ -7,7 +7,7 @@
  *
  * @copyright &copy; 1999-2009 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: redirect.php 13676 2009-05-11 22:48:03Z pdontthink $
+ * @version $Id: redirect.php 13725 2009-05-20 17:02:47Z pdontthink $
  * @package squirrelmail
  */
 
@@ -80,6 +80,10 @@ if (!sqsession_is_registered('user_is_logged_in')) {
      */
     if (function_exists('session_regenerate_id')) {
         session_regenerate_id();
+
+        // re-send session cookie so we get the right parameters on it
+        // (such as HTTPOnly, if necessary - PHP doesn't do this itself
+        sqsetcookie(session_name(),session_id(),false,$base_uri);
     }
 
     $onetimepad = OneTimePadCreate(strlen($secretkey));
